Introduction
*************

This is a Framework for Noise Cancellation in the context of gravitational wave detection.
`franc.evaluation` provides a framework to analyze and compare the effectiveness of noise mitigation techniques.
`franc.filtering` provides python implementations of different static and adaptive filtering techniques for the prediction of a correlated signal component from witness signals. The main goal is to provide a unified interface for the different filtering techniques.

:Version: |version|

Table of Contents
==================

.. toctree::
  :maxdepth: 3

  concepts_wording
  evaluating
  filtering
  adding_filters
  adding_metrics
